import java.awt
import java.awt.desktop
import java.awt.event
import java.awt.im
import java.awt.image
import java.io
import java.net
import java.util
import javax.swing
import jpype.protocol
import sun.java2d.pipe
import typing



class ComponentPeer:
    SET_LOCATION: typing.ClassVar[int] = ...
    SET_SIZE: typing.ClassVar[int] = ...
    SET_BOUNDS: typing.ClassVar[int] = ...
    SET_CLIENT_SIZE: typing.ClassVar[int] = ...
    RESET_OPERATION: typing.ClassVar[int] = ...
    NO_EMBEDDED_CHECK: typing.ClassVar[int] = ...
    DEFAULT_OPERATION: typing.ClassVar[int] = ...
    def applyShape(self, region: sun.java2d.pipe.Region) -> None: ...
    def canDetermineObscurity(self) -> bool: ...
    def checkImage(self, image: java.awt.Image, int: int, int2: int, imageObserver: java.awt.image.ImageObserver) -> int: ...
    def coalescePaintEvent(self, paintEvent: java.awt.event.PaintEvent) -> None: ...
    def createBuffers(self, int: int, bufferCapabilities: java.awt.BufferCapabilities) -> None: ...
    @typing.overload
    def createImage(self, int: int, int2: int) -> java.awt.Image: ...
    @typing.overload
    def createImage(self, imageProducer: java.awt.image.ImageProducer) -> java.awt.Image: ...
    def createVolatileImage(self, int: int, int2: int) -> java.awt.image.VolatileImage: ...
    def destroyBuffers(self) -> None: ...
    def dispose(self) -> None: ...
    def flip(self, int: int, int2: int, int3: int, int4: int, flipContents: java.awt.BufferCapabilities.FlipContents) -> None: ...
    def getBackBuffer(self) -> java.awt.Image: ...
    def getColorModel(self) -> java.awt.image.ColorModel: ...
    def getFontMetrics(self, font: java.awt.Font) -> java.awt.FontMetrics: ...
    def getGraphics(self) -> java.awt.Graphics: ...
    def getGraphicsConfiguration(self) -> java.awt.GraphicsConfiguration: ...
    def getLocationOnScreen(self) -> java.awt.Point: ...
    def getMinimumSize(self) -> java.awt.Dimension: ...
    def getPreferredSize(self) -> java.awt.Dimension: ...
    def handleEvent(self, aWTEvent: java.awt.AWTEvent) -> None: ...
    def handlesWheelScrolling(self) -> bool: ...
    def isFocusable(self) -> bool: ...
    def isObscured(self) -> bool: ...
    def isReparentSupported(self) -> bool: ...
    def layout(self) -> None: ...
    def paint(self, graphics: java.awt.Graphics) -> None: ...
    def prepareImage(self, image: java.awt.Image, int: int, int2: int, imageObserver: java.awt.image.ImageObserver) -> bool: ...
    def reparent(self, containerPeer: 'ContainerPeer') -> None: ...
    def requestFocus(self, component: java.awt.Component, boolean: bool, boolean2: bool, long: int, cause: java.awt.event.FocusEvent.Cause) -> bool: ...
    def setBackground(self, color: java.awt.Color) -> None: ...
    def setBounds(self, int: int, int2: int, int3: int, int4: int, int5: int) -> None: ...
    def setEnabled(self, boolean: bool) -> None: ...
    def setFont(self, font: java.awt.Font) -> None: ...
    def setForeground(self, color: java.awt.Color) -> None: ...
    def setVisible(self, boolean: bool) -> None: ...
    def setZOrder(self, componentPeer: 'ComponentPeer') -> None: ...
    def updateCursorImmediately(self) -> None: ...
    def updateGraphicsData(self, graphicsConfiguration: java.awt.GraphicsConfiguration) -> bool: ...

class DesktopPeer:
    def addAppEventListener(self, systemEventListener: java.awt.desktop.SystemEventListener) -> None: ...
    def browse(self, uRI: java.net.URI) -> None: ...
    def browseFileDirectory(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> bool: ...
    def disableSuddenTermination(self) -> None: ...
    def edit(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> None: ...
    def enableSuddenTermination(self) -> None: ...
    def isSupported(self, action: java.awt.Desktop.Action) -> bool: ...
    def mail(self, uRI: java.net.URI) -> None: ...
    def moveToTrash(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> bool: ...
    def open(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> None: ...
    def openHelpViewer(self) -> None: ...
    def removeAppEventListener(self, systemEventListener: java.awt.desktop.SystemEventListener) -> None: ...
    def requestForeground(self, boolean: bool) -> None: ...
    def setAboutHandler(self, aboutHandler: java.awt.desktop.AboutHandler) -> None: ...
    def setDefaultMenuBar(self, jMenuBar: javax.swing.JMenuBar) -> None: ...
    def setOpenFileHandler(self, openFilesHandler: java.awt.desktop.OpenFilesHandler) -> None: ...
    def setOpenURIHandler(self, openURIHandler: java.awt.desktop.OpenURIHandler) -> None: ...
    def setPreferencesHandler(self, preferencesHandler: java.awt.desktop.PreferencesHandler) -> None: ...
    def setPrintFileHandler(self, printFilesHandler: java.awt.desktop.PrintFilesHandler) -> None: ...
    def setQuitHandler(self, quitHandler: java.awt.desktop.QuitHandler) -> None: ...
    def setQuitStrategy(self, quitStrategy: java.awt.desktop.QuitStrategy) -> None: ...

class FontPeer: ...

class KeyboardFocusManagerPeer:
    def clearGlobalFocusOwner(self, window: java.awt.Window) -> None: ...
    def getCurrentFocusOwner(self) -> java.awt.Component: ...
    def getCurrentFocusedWindow(self) -> java.awt.Window: ...
    def setCurrentFocusOwner(self, component: java.awt.Component) -> None: ...
    def setCurrentFocusedWindow(self, window: java.awt.Window) -> None: ...

class MenuComponentPeer:
    def dispose(self) -> None: ...
    def setFont(self, font: java.awt.Font) -> None: ...

class MouseInfoPeer:
    def fillPointWithCoords(self, point: java.awt.Point) -> int: ...
    def isWindowUnderMouse(self, window: java.awt.Window) -> bool: ...

class RobotPeer:
    def getRGBPixel(self, int: int, int2: int) -> int: ...
    def getRGBPixels(self, rectangle: java.awt.Rectangle) -> typing.List[int]: ...
    def keyPress(self, int: int) -> None: ...
    def keyRelease(self, int: int) -> None: ...
    def mouseMove(self, int: int, int2: int) -> None: ...
    def mousePress(self, int: int) -> None: ...
    def mouseRelease(self, int: int) -> None: ...
    def mouseWheel(self, int: int) -> None: ...
    def useAbsoluteCoordinates(self) -> bool: ...

class SystemTrayPeer:
    def getTrayIconSize(self) -> java.awt.Dimension: ...

class TaskbarPeer:
    def getIconImage(self) -> java.awt.Image: ...
    def getMenu(self) -> java.awt.PopupMenu: ...
    def isSupported(self, feature: java.awt.Taskbar.Feature) -> bool: ...
    def requestUserAttention(self, boolean: bool, boolean2: bool) -> None: ...
    def requestWindowUserAttention(self, window: java.awt.Window) -> None: ...
    def setIconBadge(self, string: str) -> None: ...
    def setIconImage(self, image: java.awt.Image) -> None: ...
    def setMenu(self, popupMenu: java.awt.PopupMenu) -> None: ...
    def setProgressValue(self, int: int) -> None: ...
    def setWindowIconBadge(self, window: java.awt.Window, image: java.awt.Image) -> None: ...
    def setWindowProgressState(self, window: java.awt.Window, state: java.awt.Taskbar.State) -> None: ...
    def setWindowProgressValue(self, window: java.awt.Window, int: int) -> None: ...

class TrayIconPeer:
    def displayMessage(self, string: str, string2: str, string3: str) -> None: ...
    def dispose(self) -> None: ...
    def setToolTip(self, string: str) -> None: ...
    def showPopupMenu(self, int: int, int2: int) -> None: ...
    def updateImage(self) -> None: ...

class ButtonPeer(ComponentPeer):
    def setLabel(self, string: str) -> None: ...

class CanvasPeer(ComponentPeer):
    def getAppropriateGraphicsConfiguration(self, graphicsConfiguration: java.awt.GraphicsConfiguration) -> java.awt.GraphicsConfiguration: ...

class CheckboxPeer(ComponentPeer):
    def setCheckboxGroup(self, checkboxGroup: java.awt.CheckboxGroup) -> None: ...
    def setLabel(self, string: str) -> None: ...
    def setState(self, boolean: bool) -> None: ...

class ChoicePeer(ComponentPeer):
    def add(self, string: str, int: int) -> None: ...
    def remove(self, int: int) -> None: ...
    def removeAll(self) -> None: ...
    def select(self, int: int) -> None: ...

class ContainerPeer(ComponentPeer):
    def beginLayout(self) -> None: ...
    def beginValidate(self) -> None: ...
    def endLayout(self) -> None: ...
    def endValidate(self) -> None: ...
    def getInsets(self) -> java.awt.Insets: ...

class LabelPeer(ComponentPeer):
    def setAlignment(self, int: int) -> None: ...
    def setText(self, string: str) -> None: ...

class LightweightPeer(ComponentPeer): ...

class ListPeer(ComponentPeer):
    def add(self, string: str, int: int) -> None: ...
    def delItems(self, int: int, int2: int) -> None: ...
    def deselect(self, int: int) -> None: ...
    @typing.overload
    def getMinimumSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getMinimumSize(self, int: int) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self, int: int) -> java.awt.Dimension: ...
    def getSelectedIndexes(self) -> typing.List[int]: ...
    def makeVisible(self, int: int) -> None: ...
    def removeAll(self) -> None: ...
    def select(self, int: int) -> None: ...
    def setMultipleMode(self, boolean: bool) -> None: ...

class MenuBarPeer(MenuComponentPeer):
    def addHelpMenu(self, menu: java.awt.Menu) -> None: ...
    def addMenu(self, menu: java.awt.Menu) -> None: ...
    def delMenu(self, int: int) -> None: ...

class MenuItemPeer(MenuComponentPeer):
    def setEnabled(self, boolean: bool) -> None: ...
    def setLabel(self, string: str) -> None: ...

class ScrollbarPeer(ComponentPeer):
    def setLineIncrement(self, int: int) -> None: ...
    def setPageIncrement(self, int: int) -> None: ...
    def setValues(self, int: int, int2: int, int3: int, int4: int) -> None: ...

class TextComponentPeer(ComponentPeer):
    def getCaretPosition(self) -> int: ...
    def getInputMethodRequests(self) -> java.awt.im.InputMethodRequests: ...
    def getSelectionEnd(self) -> int: ...
    def getSelectionStart(self) -> int: ...
    def getText(self) -> str: ...
    def select(self, int: int, int2: int) -> None: ...
    def setCaretPosition(self, int: int) -> None: ...
    def setEditable(self, boolean: bool) -> None: ...
    def setText(self, string: str) -> None: ...

class CheckboxMenuItemPeer(MenuItemPeer):
    def setState(self, boolean: bool) -> None: ...

class MenuPeer(MenuItemPeer):
    def addItem(self, menuItem: java.awt.MenuItem) -> None: ...
    def addSeparator(self) -> None: ...
    def delItem(self, int: int) -> None: ...

class PanelPeer(ContainerPeer): ...

class ScrollPanePeer(ContainerPeer):
    def childResized(self, int: int, int2: int) -> None: ...
    def getHScrollbarHeight(self) -> int: ...
    def getVScrollbarWidth(self) -> int: ...
    def setScrollPosition(self, int: int, int2: int) -> None: ...
    def setUnitIncrement(self, adjustable: java.awt.Adjustable, int: int) -> None: ...
    def setValue(self, adjustable: java.awt.Adjustable, int: int) -> None: ...

class TextAreaPeer(TextComponentPeer):
    @typing.overload
    def getMinimumSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getMinimumSize(self, int: int, int2: int) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self, int: int, int2: int) -> java.awt.Dimension: ...
    def insert(self, string: str, int: int) -> None: ...
    def replaceRange(self, string: str, int: int, int2: int) -> None: ...

class TextFieldPeer(TextComponentPeer):
    @typing.overload
    def getMinimumSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getMinimumSize(self, int: int) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self) -> java.awt.Dimension: ...
    @typing.overload
    def getPreferredSize(self, int: int) -> java.awt.Dimension: ...
    def setEchoChar(self, char: str) -> None: ...

class WindowPeer(ContainerPeer):
    def repositionSecurityWarning(self) -> None: ...
    def setModalBlocked(self, dialog: java.awt.Dialog, boolean: bool) -> None: ...
    def setOpacity(self, float: float) -> None: ...
    def setOpaque(self, boolean: bool) -> None: ...
    def toBack(self) -> None: ...
    def toFront(self) -> None: ...
    def updateAlwaysOnTopState(self) -> None: ...
    def updateFocusableWindowState(self) -> None: ...
    def updateIconImages(self) -> None: ...
    def updateMinimumSize(self) -> None: ...
    def updateWindow(self) -> None: ...

class DialogPeer(WindowPeer):
    def blockWindows(self, list: java.util.List[java.awt.Window]) -> None: ...
    def setResizable(self, boolean: bool) -> None: ...
    def setTitle(self, string: str) -> None: ...

class FramePeer(WindowPeer):
    def emulateActivation(self, boolean: bool) -> None: ...
    def getBoundsPrivate(self) -> java.awt.Rectangle: ...
    def getState(self) -> int: ...
    def setBoundsPrivate(self, int: int, int2: int, int3: int, int4: int) -> None: ...
    def setMaximizedBounds(self, rectangle: java.awt.Rectangle) -> None: ...
    def setMenuBar(self, menuBar: java.awt.MenuBar) -> None: ...
    def setResizable(self, boolean: bool) -> None: ...
    def setState(self, int: int) -> None: ...
    def setTitle(self, string: str) -> None: ...

class PopupMenuPeer(MenuPeer):
    def show(self, event: java.awt.Event) -> None: ...

class FileDialogPeer(DialogPeer):
    def setDirectory(self, string: str) -> None: ...
    def setFile(self, string: str) -> None: ...
    def setFilenameFilter(self, filenameFilter: typing.Union[java.io.FilenameFilter, typing.Callable]) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.peer")``.

    ButtonPeer: typing.Type[ButtonPeer]
    CanvasPeer: typing.Type[CanvasPeer]
    CheckboxMenuItemPeer: typing.Type[CheckboxMenuItemPeer]
    CheckboxPeer: typing.Type[CheckboxPeer]
    ChoicePeer: typing.Type[ChoicePeer]
    ComponentPeer: typing.Type[ComponentPeer]
    ContainerPeer: typing.Type[ContainerPeer]
    DesktopPeer: typing.Type[DesktopPeer]
    DialogPeer: typing.Type[DialogPeer]
    FileDialogPeer: typing.Type[FileDialogPeer]
    FontPeer: typing.Type[FontPeer]
    FramePeer: typing.Type[FramePeer]
    KeyboardFocusManagerPeer: typing.Type[KeyboardFocusManagerPeer]
    LabelPeer: typing.Type[LabelPeer]
    LightweightPeer: typing.Type[LightweightPeer]
    ListPeer: typing.Type[ListPeer]
    MenuBarPeer: typing.Type[MenuBarPeer]
    MenuComponentPeer: typing.Type[MenuComponentPeer]
    MenuItemPeer: typing.Type[MenuItemPeer]
    MenuPeer: typing.Type[MenuPeer]
    MouseInfoPeer: typing.Type[MouseInfoPeer]
    PanelPeer: typing.Type[PanelPeer]
    PopupMenuPeer: typing.Type[PopupMenuPeer]
    RobotPeer: typing.Type[RobotPeer]
    ScrollPanePeer: typing.Type[ScrollPanePeer]
    ScrollbarPeer: typing.Type[ScrollbarPeer]
    SystemTrayPeer: typing.Type[SystemTrayPeer]
    TaskbarPeer: typing.Type[TaskbarPeer]
    TextAreaPeer: typing.Type[TextAreaPeer]
    TextComponentPeer: typing.Type[TextComponentPeer]
    TextFieldPeer: typing.Type[TextFieldPeer]
    TrayIconPeer: typing.Type[TrayIconPeer]
    WindowPeer: typing.Type[WindowPeer]



import java.lang
import java.util.concurrent
import scala
import scala.collection
import scala.collection.generic
import scala.collection.immutable
import scala.concurrent.duration
import scala.concurrent.forkjoin
import scala.concurrent.impl
import scala.reflect
import scala.runtime
import scala.util
import typing



class Await:
    _ready__T = typing.TypeVar('_ready__T')  # <T>
    @staticmethod
    def ready(awaitable: 'Awaitable'[_ready__T], atMost: scala.concurrent.duration.Duration) -> 'Awaitable'[_ready__T]: ...
    _result__T = typing.TypeVar('_result__T')  # <T>
    @staticmethod
    def result(awaitable: 'Awaitable'[_result__T], atMost: scala.concurrent.duration.Duration) -> _result__T: ...

class AwaitPermission: ...

_Awaitable__T = typing.TypeVar('_Awaitable__T')  # <T>
class Awaitable(typing.Generic[_Awaitable__T]):
    def ready(self, atMost: scala.concurrent.duration.Duration, permit: 'CanAwait') -> 'Awaitable'[_Awaitable__T]: ...
    def result(self, atMost: scala.concurrent.duration.Duration, permit: 'CanAwait') -> _Awaitable__T: ...

class CanAwait: ...

_Channel__LinkedList__A = typing.TypeVar('_Channel__LinkedList__A')  # <A>
_Channel__A = typing.TypeVar('_Channel__A')  # <A>
class Channel(typing.Generic[_Channel__A]):
    def __init__(self): ...
    def read(self) -> _Channel__A: ...
    def write(self, x: _Channel__A) -> None: ...
    class LinkedList(typing.Generic[_Channel__LinkedList__A]):
        $outer: 'Channel' = ...
        def __init__(self, $outer: 'Channel'): ...
        def elem(self) -> typing.Any: ...
        def elem_$eq(self, x$1: typing.Any) -> None: ...
        def next(self) -> 'Channel.LinkedList'[typing.Any]: ...
        def next_$eq(self, x$1: 'Channel.LinkedList'[typing.Any]) -> None: ...

_DelayedLazyVal__T = typing.TypeVar('_DelayedLazyVal__T')  # <T>
class DelayedLazyVal(typing.Generic[_DelayedLazyVal__T]):
    scala$concurrent$DelayedLazyVal$$body: scala.Function0 = ...
    scala$concurrent$DelayedLazyVal$$_isDone: bool = ...
    def __init__(self, f: scala.Function0[_DelayedLazyVal__T], body: scala.Function0[scala.runtime.BoxedUnit], exec_: 'ExecutionContext'): ...
    def apply(self) -> _DelayedLazyVal__T: ...
    def isDone(self) -> bool: ...

class ExecutionContext:
    @staticmethod
    def $init$($this: 'ExecutionContext') -> None: ...
    @staticmethod
    def defaultReporter() -> scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]: ...
    def execute(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    @typing.overload
    @staticmethod
    def fromExecutor(e: java.util.concurrent.Executor) -> 'ExecutionContextExecutor': ...
    @typing.overload
    @staticmethod
    def fromExecutor(e: java.util.concurrent.Executor, reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]) -> 'ExecutionContextExecutor': ...
    @typing.overload
    @staticmethod
    def fromExecutorService(e: java.util.concurrent.ExecutorService) -> 'ExecutionContextExecutorService': ...
    @typing.overload
    @staticmethod
    def fromExecutorService(e: java.util.concurrent.ExecutorService, reporter: scala.Function1[java.lang.Throwable, scala.runtime.BoxedUnit]) -> 'ExecutionContextExecutorService': ...
    def prepare(self) -> 'ExecutionContext': ...
    def reportFailure(self, cause: java.lang.Throwable) -> None: ...
    class Implicits$:
        MODULE$: typing.ClassVar['ExecutionContext.Implicits.'] = ...
        def __init__(self): ...

class JavaConversions:
    @typing.overload
    @staticmethod
    def asExecutionContext(exec_: java.util.concurrent.Executor) -> 'ExecutionContextExecutor': ...
    @typing.overload
    @staticmethod
    def asExecutionContext(exec_: java.util.concurrent.ExecutorService) -> 'ExecutionContextExecutorService': ...

class Lock:
    def __init__(self): ...
    def acquire(self) -> None: ...
    def available(self) -> bool: ...
    def available_$eq(self, x$1: bool) -> None: ...
    def release(self) -> None: ...

class OnCompleteRunnable: ...

_Promise__T = typing.TypeVar('_Promise__T')  # <T>
class Promise(typing.Generic[_Promise__T]):
    @staticmethod
    def $init$($this: 'Promise') -> None: ...
    _apply__T = typing.TypeVar('_apply__T')  # <T>
    @staticmethod
    def apply() -> 'Promise'[_apply__T]: ...
    def complete(self, result: scala.util.Try[_Promise__T]) -> 'Promise'[_Promise__T]: ...
    def completeWith(self, other: 'Future'[_Promise__T]) -> 'Promise'[_Promise__T]: ...
    _failed__T = typing.TypeVar('_failed__T')  # <T>
    @staticmethod
    def failed(exception: java.lang.Throwable) -> 'Promise'[_failed__T]: ...
    def failure(self, cause: java.lang.Throwable) -> 'Promise'[_Promise__T]: ...
    _fromTry__T = typing.TypeVar('_fromTry__T')  # <T>
    @staticmethod
    def fromTry(result: scala.util.Try[_fromTry__T]) -> 'Promise'[_fromTry__T]: ...
    def future(self) -> 'Future'[_Promise__T]: ...
    def isCompleted(self) -> bool: ...
    def success(self, value: _Promise__T) -> 'Promise'[_Promise__T]: ...
    _successful__T = typing.TypeVar('_successful__T')  # <T>
    @staticmethod
    def successful(result: _successful__T) -> 'Promise'[_successful__T]: ...
    def tryComplete(self, result: scala.util.Try[_Promise__T]) -> bool: ...
    def tryCompleteWith(self, other: 'Future'[_Promise__T]) -> 'Promise'[_Promise__T]: ...
    def tryFailure(self, cause: java.lang.Throwable) -> bool: ...
    def trySuccess(self, value: _Promise__T) -> bool: ...

_SyncChannel__A = typing.TypeVar('_SyncChannel__A')  # <A>
class SyncChannel(typing.Generic[_SyncChannel__A]):
    def __init__(self): ...
    def read(self) -> _SyncChannel__A: ...
    def write(self, data: _SyncChannel__A) -> None: ...

_SyncVar__A = typing.TypeVar('_SyncVar__A')  # <A>
class SyncVar(typing.Generic[_SyncVar__A]):
    def __init__(self): ...
    @typing.overload
    def get(self) -> _SyncVar__A: ...
    @typing.overload
    def get(self, timeout: int) -> scala.Option[_SyncVar__A]: ...
    def isSet(self) -> bool: ...
    def put(self, x: _SyncVar__A) -> None: ...
    def set(self, x: _SyncVar__A) -> None: ...
    @typing.overload
    def take(self) -> _SyncVar__A: ...
    @typing.overload
    def take(self, timeout: int) -> _SyncVar__A: ...
    def unset(self) -> None: ...

class package:
    _blocking__T = typing.TypeVar('_blocking__T')  # <T>
    @staticmethod
    def blocking(body: scala.Function0[_blocking__T]) -> _blocking__T: ...
    _future__T = typing.TypeVar('_future__T')  # <T>
    @staticmethod
    def future(body: scala.Function0[_future__T], executor: ExecutionContext) -> 'Future'[_future__T]: ...
    _promise__T = typing.TypeVar('_promise__T')  # <T>
    @staticmethod
    def promise() -> Promise[_promise__T]: ...

class ExecutionContextExecutor(ExecutionContext, java.util.concurrent.Executor): ...

class ExecutionContextExecutorService(ExecutionContextExecutor, java.util.concurrent.ExecutorService): ...

class BatchingExecutor(java.util.concurrent.Executor):
    @staticmethod
    def $init$($this: 'BatchingExecutor') -> None: ...
    def batchable(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> bool: ...
    def execute(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    def scala$concurrent$BatchingExecutor$$_tasksLocal(self) -> java.lang.ThreadLocal[scala.collection.immutable.List[java.lang.Runnable]]: ...
    def scala$concurrent$BatchingExecutor$_setter_$scala$concurrent$BatchingExecutor$$_tasksLocal_$eq(self, x$1: java.lang.ThreadLocal[scala.collection.immutable.List[typing.Union[java.lang.Runnable, typing.Callable]]]) -> None: ...
    def unbatchedExecute(self, r: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    class Batch(java.lang.Runnable, scala.concurrent.BlockContext):
        $outer: 'BatchingExecutor' = ...
        def __init__(self, $outer: 'BatchingExecutor', initial: scala.collection.immutable.List[typing.Union[java.lang.Runnable, typing.Callable]]): ...
        _blockOn__T = typing.TypeVar('_blockOn__T')  # <T>
        def blockOn(self, thunk: scala.Function0[_blockOn__T], permission: CanAwait) -> _blockOn__T: ...
        def initial(self) -> scala.collection.immutable.List[java.lang.Runnable]: ...
        def run(self) -> None: ...

class BlockContext:
    _blockOn__T = typing.TypeVar('_blockOn__T')  # <T>
    def blockOn(self, thunk: scala.Function0[_blockOn__T], permission: CanAwait) -> _blockOn__T: ...
    @staticmethod
    def current() -> 'BlockContext': ...
    @staticmethod
    def defaultBlockContext() -> 'BlockContext': ...
    _withBlockContext__T = typing.TypeVar('_withBlockContext__T')  # <T>
    @staticmethod
    def withBlockContext(blockContext: 'BlockContext', body: scala.Function0[_withBlockContext__T]) -> _withBlockContext__T: ...
    class DefaultBlockContext$(scala.concurrent.BlockContext):
        MODULE$: typing.ClassVar['BlockContext.DefaultBlockContext.'] = ...
        def __init__(self): ...
        _blockOn__T = typing.TypeVar('_blockOn__T')  # <T>
        def blockOn(self, thunk: scala.Function0[_blockOn__T], permission: CanAwait) -> _blockOn__T: ...

_Future__T = typing.TypeVar('_Future__T')  # <T>
class Future(Awaitable[_Future__T], typing.Generic[_Future__T]):
    @staticmethod
    def $init$($this: 'Future') -> None: ...
    _andThen__U = typing.TypeVar('_andThen__U')  # <U>
    def andThen(self, pf: scala.PartialFunction[scala.util.Try[_Future__T], _andThen__U], executor: ExecutionContext) -> 'Future'[_Future__T]: ...
    _apply__T = typing.TypeVar('_apply__T')  # <T>
    @staticmethod
    def apply(body: scala.Function0[_apply__T], executor: ExecutionContext) -> 'Future'[_apply__T]: ...
    _collect__S = typing.TypeVar('_collect__S')  # <S>
    def collect(self, pf: scala.PartialFunction[_Future__T, _collect__S], executor: ExecutionContext) -> 'Future'[_collect__S]: ...
    def failed(self) -> 'Future'[java.lang.Throwable]: ...
    _fallbackTo__U = typing.TypeVar('_fallbackTo__U')  # <U>
    def fallbackTo(self, that: 'Future'[_fallbackTo__U]) -> 'Future'[_fallbackTo__U]: ...
    def filter(self, p: scala.Function1[_Future__T, typing.Any], executor: ExecutionContext) -> 'Future'[_Future__T]: ...
    _find_0__T = typing.TypeVar('_find_0__T')  # <T>
    _find_1__T = typing.TypeVar('_find_1__T')  # <T>
    @typing.overload
    @staticmethod
    def find(futures: scala.collection.TraversableOnce['Future'[_find_0__T]], p: scala.Function1[_find_0__T, typing.Any], executor: ExecutionContext) -> 'Future'[scala.Option[_find_0__T]]: ...
    @typing.overload
    @staticmethod
    def find(futures: scala.collection.immutable.Iterable['Future'[_find_1__T]], p: scala.Function1[_find_1__T, typing.Any], executor: ExecutionContext) -> 'Future'[scala.Option[_find_1__T]]: ...
    _firstCompletedOf__T = typing.TypeVar('_firstCompletedOf__T')  # <T>
    @staticmethod
    def firstCompletedOf(futures: scala.collection.TraversableOnce['Future'[_firstCompletedOf__T]], executor: ExecutionContext) -> 'Future'[_firstCompletedOf__T]: ...
    _flatMap__S = typing.TypeVar('_flatMap__S')  # <S>
    def flatMap(self, f: scala.Function1[_Future__T, 'Future'[_flatMap__S]], executor: ExecutionContext) -> 'Future'[_flatMap__S]: ...
    _flatten__S = typing.TypeVar('_flatten__S')  # <S>
    def flatten(self, ev: scala.Predef..less.colon.less[_Future__T, 'Future'[_flatten__S]]) -> 'Future'[_flatten__S]: ...
    _fold__T = typing.TypeVar('_fold__T')  # <T>
    _fold__R = typing.TypeVar('_fold__R')  # <R>
    @staticmethod
    def fold(futures: scala.collection.TraversableOnce['Future'[_fold__T]], zero: _fold__R, op: scala.Function2[_fold__R, _fold__T, _fold__R], executor: ExecutionContext) -> 'Future'[_fold__R]: ...
    _foldLeft__T = typing.TypeVar('_foldLeft__T')  # <T>
    _foldLeft__R = typing.TypeVar('_foldLeft__R')  # <R>
    @staticmethod
    def foldLeft(futures: scala.collection.immutable.Iterable['Future'[_foldLeft__T]], zero: _foldLeft__R, op: scala.Function2[_foldLeft__R, _foldLeft__T, _foldLeft__R], executor: ExecutionContext) -> 'Future'[_foldLeft__R]: ...
    _foreach__U = typing.TypeVar('_foreach__U')  # <U>
    def foreach(self, f: scala.Function1[_Future__T, _foreach__U], executor: ExecutionContext) -> None: ...
    _fromTry__T = typing.TypeVar('_fromTry__T')  # <T>
    @staticmethod
    def fromTry(result: scala.util.Try[_fromTry__T]) -> 'Future'[_fromTry__T]: ...
    def isCompleted(self) -> bool: ...
    _map__S = typing.TypeVar('_map__S')  # <S>
    def map(self, f: scala.Function1[_Future__T, _map__S], executor: ExecutionContext) -> 'Future'[_map__S]: ...
    _mapTo__S = typing.TypeVar('_mapTo__S')  # <S>
    def mapTo(self, tag: scala.reflect.ClassTag[_mapTo__S]) -> 'Future'[_mapTo__S]: ...
    _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
    def onComplete(self, f: scala.Function1[scala.util.Try[_Future__T], _onComplete__U], executor: ExecutionContext) -> None: ...
    _onFailure__U = typing.TypeVar('_onFailure__U')  # <U>
    def onFailure(self, pf: scala.PartialFunction[java.lang.Throwable, _onFailure__U], executor: ExecutionContext) -> None: ...
    _onSuccess__U = typing.TypeVar('_onSuccess__U')  # <U>
    def onSuccess(self, pf: scala.PartialFunction[_Future__T, _onSuccess__U], executor: ExecutionContext) -> None: ...
    _recover__U = typing.TypeVar('_recover__U')  # <U>
    def recover(self, pf: scala.PartialFunction[java.lang.Throwable, _recover__U], executor: ExecutionContext) -> 'Future'[_recover__U]: ...
    _recoverWith__U = typing.TypeVar('_recoverWith__U')  # <U>
    def recoverWith(self, pf: scala.PartialFunction[java.lang.Throwable, 'Future'[_recoverWith__U]], executor: ExecutionContext) -> 'Future'[_recoverWith__U]: ...
    _reduce__T = typing.TypeVar('_reduce__T')  # <T>
    _reduce__R = typing.TypeVar('_reduce__R')  # <R>
    @staticmethod
    def reduce(futures: scala.collection.TraversableOnce['Future'[_reduce__T]], op: scala.Function2[_reduce__R, _reduce__T, _reduce__R], executor: ExecutionContext) -> 'Future'[_reduce__R]: ...
    _reduceLeft__T = typing.TypeVar('_reduceLeft__T')  # <T>
    _reduceLeft__R = typing.TypeVar('_reduceLeft__R')  # <R>
    @staticmethod
    def reduceLeft(futures: scala.collection.immutable.Iterable['Future'[_reduceLeft__T]], op: scala.Function2[_reduceLeft__R, _reduceLeft__T, _reduceLeft__R], executor: ExecutionContext) -> 'Future'[_reduceLeft__R]: ...
    _sequence__A = typing.TypeVar('_sequence__A')  # <A>
    _sequence__M = typing.TypeVar('_sequence__M', bound=scala.collection.TraversableOnce)  # <M>
    @staticmethod
    def sequence(in_: _sequence__M, cbf: scala.collection.generic.CanBuildFrom[_sequence__M, _sequence__A, _sequence__M], executor: ExecutionContext) -> 'Future'[_sequence__M]: ...
    _successful__T = typing.TypeVar('_successful__T')  # <T>
    @staticmethod
    def successful(result: _successful__T) -> 'Future'[_successful__T]: ...
    _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
    _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
    @typing.overload
    def transform(self, f: scala.Function1[scala.util.Try[_Future__T], scala.util.Try[_transform_0__S]], executor: ExecutionContext) -> 'Future'[_transform_0__S]: ...
    @typing.overload
    def transform(self, s: scala.Function1[_Future__T, _transform_1__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: ExecutionContext) -> 'Future'[_transform_1__S]: ...
    _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
    def transformWith(self, f: scala.Function1[scala.util.Try[_Future__T], 'Future'[_transformWith__S]], executor: ExecutionContext) -> 'Future'[_transformWith__S]: ...
    _traverse__A = typing.TypeVar('_traverse__A')  # <A>
    _traverse__B = typing.TypeVar('_traverse__B')  # <B>
    _traverse__M = typing.TypeVar('_traverse__M', bound=scala.collection.TraversableOnce)  # <M>
    @staticmethod
    def traverse(in_: _traverse__M, fn: scala.Function1[_traverse__A, 'Future'[_traverse__B]], cbf: scala.collection.generic.CanBuildFrom[_traverse__M, _traverse__B, _traverse__M], executor: ExecutionContext) -> 'Future'[_traverse__M]: ...
    @staticmethod
    def unit() -> 'Future'[scala.runtime.BoxedUnit]: ...
    def value(self) -> scala.Option[scala.util.Try[_Future__T]]: ...
    def withFilter(self, p: scala.Function1[_Future__T, typing.Any], executor: ExecutionContext) -> 'Future'[_Future__T]: ...
    _zip__U = typing.TypeVar('_zip__U')  # <U>
    def zip(self, that: 'Future'[_zip__U]) -> 'Future'[scala.Tuple2[_Future__T, _zip__U]]: ...
    _zipWith__U = typing.TypeVar('_zipWith__U')  # <U>
    _zipWith__R = typing.TypeVar('_zipWith__R')  # <R>
    def zipWith(self, that: 'Future'[_zipWith__U], f: scala.Function2[_Future__T, _zipWith__U, _zipWith__R], executor: ExecutionContext) -> 'Future'[_zipWith__R]: ...
    class InternalCallbackExecutor$(ExecutionContext, BatchingExecutor):
        MODULE$: typing.ClassVar['Future.InternalCallbackExecutor.'] = ...
        def __init__(self): ...
        def batchable(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> bool: ...
        def execute(self, runnable: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
        def prepare(self) -> ExecutionContext: ...
        def reportFailure(self, t: java.lang.Throwable) -> None: ...
        def scala$concurrent$BatchingExecutor$$_tasksLocal(self) -> java.lang.ThreadLocal[scala.collection.immutable.List[java.lang.Runnable]]: ...
        def scala$concurrent$BatchingExecutor$_setter_$scala$concurrent$BatchingExecutor$$_tasksLocal_$eq(self, x$1: java.lang.ThreadLocal[scala.collection.immutable.List[typing.Union[java.lang.Runnable, typing.Callable]]]) -> None: ...
        def unbatchedExecute(self, r: typing.Union[java.lang.Runnable, typing.Callable]) -> None: ...
    class never$(scala.concurrent.Future[scala.runtime.Nothing.]):
        MODULE$: typing.ClassVar['Future.never.'] = ...
        def __init__(self): ...
        _andThen__U = typing.TypeVar('_andThen__U')  # <U>
        def andThen(self, pf: scala.PartialFunction[scala.util.Try[scala.runtime.Nothing.], _andThen__U], executor: ExecutionContext) -> 'Future'[scala.runtime.Nothing.]: ...
        _collect__S = typing.TypeVar('_collect__S')  # <S>
        def collect(self, pf: scala.PartialFunction[scala.runtime.Nothing., _collect__S], executor: ExecutionContext) -> 'Future'[_collect__S]: ...
        def failed(self) -> 'Future'[java.lang.Throwable]: ...
        _fallbackTo__U = typing.TypeVar('_fallbackTo__U')  # <U>
        def fallbackTo(self, that: 'Future'[_fallbackTo__U]) -> 'Future'[_fallbackTo__U]: ...
        def filter(self, p: scala.Function1[scala.runtime.Nothing., typing.Any], executor: ExecutionContext) -> 'Future'[scala.runtime.Nothing.]: ...
        _flatMap__S = typing.TypeVar('_flatMap__S')  # <S>
        def flatMap(self, f: scala.Function1[scala.runtime.Nothing., 'Future'[_flatMap__S]], executor: ExecutionContext) -> 'Future'[_flatMap__S]: ...
        _flatten__S = typing.TypeVar('_flatten__S')  # <S>
        def flatten(self, ev: scala.Predef..less.colon.less[scala.runtime.Nothing., 'Future'[_flatten__S]]) -> 'Future'[_flatten__S]: ...
        _foreach__U = typing.TypeVar('_foreach__U')  # <U>
        def foreach(self, f: scala.Function1[scala.runtime.Nothing., _foreach__U], executor: ExecutionContext) -> None: ...
        def isCompleted(self) -> bool: ...
        _map__S = typing.TypeVar('_map__S')  # <S>
        def map(self, f: scala.Function1[scala.runtime.Nothing., _map__S], executor: ExecutionContext) -> 'Future'[_map__S]: ...
        _mapTo__S = typing.TypeVar('_mapTo__S')  # <S>
        def mapTo(self, tag: scala.reflect.ClassTag[_mapTo__S]) -> 'Future'[_mapTo__S]: ...
        _onComplete__U = typing.TypeVar('_onComplete__U')  # <U>
        def onComplete(self, f: scala.Function1[scala.util.Try[scala.runtime.Nothing.], _onComplete__U], executor: ExecutionContext) -> None: ...
        _onFailure__U = typing.TypeVar('_onFailure__U')  # <U>
        def onFailure(self, pf: scala.PartialFunction[java.lang.Throwable, _onFailure__U], executor: ExecutionContext) -> None: ...
        _onSuccess__U = typing.TypeVar('_onSuccess__U')  # <U>
        def onSuccess(self, pf: scala.PartialFunction[scala.runtime.Nothing., _onSuccess__U], executor: ExecutionContext) -> None: ...
        def ready(self, atMost: scala.concurrent.duration.Duration, permit: CanAwait) -> 'Future.never.': ...
        _recover__U = typing.TypeVar('_recover__U')  # <U>
        def recover(self, pf: scala.PartialFunction[java.lang.Throwable, _recover__U], executor: ExecutionContext) -> 'Future'[_recover__U]: ...
        _recoverWith__U = typing.TypeVar('_recoverWith__U')  # <U>
        def recoverWith(self, pf: scala.PartialFunction[java.lang.Throwable, 'Future'[_recoverWith__U]], executor: ExecutionContext) -> 'Future'[_recoverWith__U]: ...
        def result(self, atMost: scala.concurrent.duration.Duration, permit: CanAwait) -> scala.runtime.Nothing.: ...
        def toString(self) -> str: ...
        _transform_0__S = typing.TypeVar('_transform_0__S')  # <S>
        _transform_1__S = typing.TypeVar('_transform_1__S')  # <S>
        @typing.overload
        def transform(self, s: scala.Function1[scala.runtime.Nothing., _transform_0__S], f: scala.Function1[java.lang.Throwable, java.lang.Throwable], executor: ExecutionContext) -> 'Future'[_transform_0__S]: ...
        @typing.overload
        def transform(self, f: scala.Function1[scala.util.Try[scala.runtime.Nothing.], scala.util.Try[_transform_1__S]], executor: ExecutionContext) -> 'Future'[_transform_1__S]: ...
        _transformWith__S = typing.TypeVar('_transformWith__S')  # <S>
        def transformWith(self, f: scala.Function1[scala.util.Try[scala.runtime.Nothing.], 'Future'[_transformWith__S]], executor: ExecutionContext) -> 'Future'[_transformWith__S]: ...
        def value(self) -> scala.Option[scala.util.Try[scala.runtime.Nothing.]]: ...
        def withFilter(self, p: scala.Function1[scala.runtime.Nothing., typing.Any], executor: ExecutionContext) -> 'Future'[scala.runtime.Nothing.]: ...
        _zip__U = typing.TypeVar('_zip__U')  # <U>
        def zip(self, that: 'Future'[_zip__U]) -> 'Future'[scala.Tuple2[scala.runtime.Nothing., _zip__U]]: ...
        _zipWith__U = typing.TypeVar('_zipWith__U')  # <U>
        _zipWith__R = typing.TypeVar('_zipWith__R')  # <R>
        def zipWith(self, that: 'Future'[_zipWith__U], f: scala.Function2[scala.runtime.Nothing., _zipWith__U, _zipWith__R], executor: ExecutionContext) -> 'Future'[_zipWith__R]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.concurrent")``.

    Await: typing.Type[Await]
    AwaitPermission: typing.Type[AwaitPermission]
    Awaitable: typing.Type[Awaitable]
    BatchingExecutor: typing.Type[BatchingExecutor]
    BlockContext: typing.Type[BlockContext]
    CanAwait: typing.Type[CanAwait]
    Channel: typing.Type[Channel]
    DelayedLazyVal: typing.Type[DelayedLazyVal]
    ExecutionContext: typing.Type[ExecutionContext]
    ExecutionContextExecutor: typing.Type[ExecutionContextExecutor]
    ExecutionContextExecutorService: typing.Type[ExecutionContextExecutorService]
    Future: typing.Type[Future]
    JavaConversions: typing.Type[JavaConversions]
    Lock: typing.Type[Lock]
    OnCompleteRunnable: typing.Type[OnCompleteRunnable]
    Promise: typing.Type[Promise]
    SyncChannel: typing.Type[SyncChannel]
    SyncVar: typing.Type[SyncVar]
    package: typing.Type[package]
    duration: scala.concurrent.duration.__module_protocol__
    forkjoin: scala.concurrent.forkjoin.__module_protocol__
    impl: scala.concurrent.impl.__module_protocol__



import java.lang
import org.ergoplatform.appkit
import org.ergoplatform.appkit.cli
import org.ergoplatform.appkit.config
import scala
import scala.collection
import scala.runtime
import typing



class AddressPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class BooleanPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class Cmd:
    def __init__(self): ...
    def apiKey(self) -> java.lang.String: ...
    def apiUrl(self) -> java.lang.String: ...
    def error(self, msg: typing.Union[java.lang.String, str]) -> scala.runtime.Nothing.: ...
    _loggedStep__T = typing.TypeVar('_loggedStep__T')  # <T>
    def loggedStep(self, msg: typing.Union[java.lang.String, str], console: org.ergoplatform.appkit.cli.Console, step: scala.Function0[_loggedStep__T]) -> _loggedStep__T: ...
    def name(self) -> java.lang.String: ...
    def networkType(self) -> org.ergoplatform.appkit.NetworkType: ...
    def run(self, ctx: org.ergoplatform.appkit.cli.AppContext) -> None: ...
    def toolConf(self) -> org.ergoplatform.appkit.config.ErgoToolConfig: ...

class CmdArgInput:
    def __init__(self): ...
    def input(self, ctx: org.ergoplatform.appkit.cli.AppContext, cmd: 'CmdDescriptor', parameter: 'CmdParameter') -> typing.Any: ...

class CmdArgParser:
    def __init__(self): ...
    def parse(self, cmd: 'CmdDescriptor', p: 'CmdParameter', rawArg: typing.Union[java.lang.String, str]) -> typing.Any: ...

class CmdDescriptor:
    def __init__(self, name: typing.Union[java.lang.String, str], cmdParamSyntax: typing.Union[java.lang.String, str], description: typing.Union[java.lang.String, str]): ...
    def BaseDocUrl(self) -> java.lang.String: ...
    def cmdParamSyntax(self) -> java.lang.String: ...
    def createCmd(self, ctx: org.ergoplatform.appkit.cli.AppContext) -> Cmd: ...
    def description(self) -> java.lang.String: ...
    def docUrl(self) -> java.lang.String: ...
    def error(self, msg: typing.Union[java.lang.String, str]) -> scala.runtime.Nothing.: ...
    def name(self) -> java.lang.String: ...
    def parameters(self) -> scala.collection.Seq['CmdParameter']: ...
    def parseArgs(self, ctx: org.ergoplatform.appkit.cli.AppContext, args: scala.collection.Seq[typing.Union[java.lang.String, str]]) -> scala.collection.Seq[typing.Any]: ...
    def printUsage(self, console: org.ergoplatform.appkit.cli.Console) -> org.ergoplatform.appkit.cli.Console: ...
    def usageError(self, msg: typing.Union[java.lang.String, str]) -> scala.runtime.Nothing.: ...

class CmdException(java.lang.RuntimeException, scala.Product, scala.Serializable):
    def __init__(self, message: typing.Union[java.lang.String, str], cmd: Cmd, cause: java.lang.Throwable): ...
    @staticmethod
    def $lessinit$greater$default$3() -> java.lang.Throwable: ...
    @staticmethod
    def apply(message: typing.Union[java.lang.String, str], cmd: Cmd, cause: java.lang.Throwable) -> 'CmdException': ...
    @staticmethod
    def apply$default$3() -> java.lang.Throwable: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cause(self) -> java.lang.Throwable: ...
    def cmd(self) -> Cmd: ...
    def copy(self, message: typing.Union[java.lang.String, str], cmd: Cmd, cause: java.lang.Throwable) -> 'CmdException': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> Cmd: ...
    def copy$default$3(self) -> java.lang.Throwable: ...
    @staticmethod
    def curried() -> scala.Function1[java.lang.String, scala.Function1[Cmd, scala.Function1[java.lang.Throwable, 'CmdException']]]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def message(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple3[java.lang.String, Cmd, java.lang.Throwable], 'CmdException']: ...
    @staticmethod
    def unapply(x$0: 'CmdException') -> scala.Option[scala.Tuple3[java.lang.String, Cmd, java.lang.Throwable]]: ...

class CmdParameter(scala.Product, scala.Serializable):
    def __init__(self, name: typing.Union[java.lang.String, str], displayName: typing.Union[java.lang.String, str], tpe: 'PType', description: typing.Union[java.lang.String, str], defaultValue: scala.Option[typing.Union[java.lang.String, str]], interactiveInput: scala.Option[CmdArgInput], argParser: scala.Option[CmdArgParser]): ...
    @typing.overload
    @staticmethod
    def apply(name: typing.Union[java.lang.String, str], displayName: typing.Union[java.lang.String, str], tpe: 'PType', description: typing.Union[java.lang.String, str], defaultValue: scala.Option[typing.Union[java.lang.String, str]], interactiveInput: scala.Option[CmdArgInput], argParser: scala.Option[CmdArgParser]) -> 'CmdParameter': ...
    @typing.overload
    @staticmethod
    def apply(name: typing.Union[java.lang.String, str], tpe: 'PType', description: typing.Union[java.lang.String, str], defaultValue: scala.Option[typing.Union[java.lang.String, str]], interactiveInput: scala.Option[CmdArgInput]) -> 'CmdParameter': ...
    @staticmethod
    def apply$default$4() -> scala.Option[java.lang.String]: ...
    @staticmethod
    def apply$default$5() -> scala.Option[CmdArgInput]: ...
    def argParser(self) -> scala.Option[CmdArgParser]: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, name: typing.Union[java.lang.String, str], displayName: typing.Union[java.lang.String, str], tpe: 'PType', description: typing.Union[java.lang.String, str], defaultValue: scala.Option[typing.Union[java.lang.String, str]], interactiveInput: scala.Option[CmdArgInput], argParser: scala.Option[CmdArgParser]) -> 'CmdParameter': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> java.lang.String: ...
    def copy$default$3(self) -> 'PType': ...
    def copy$default$4(self) -> java.lang.String: ...
    def copy$default$5(self) -> scala.Option[java.lang.String]: ...
    def copy$default$6(self) -> scala.Option[CmdArgInput]: ...
    def copy$default$7(self) -> scala.Option[CmdArgParser]: ...
    def defaultValue(self) -> scala.Option[java.lang.String]: ...
    def description(self) -> java.lang.String: ...
    def displayName(self) -> java.lang.String: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def interactiveInput(self) -> scala.Option[CmdArgInput]: ...
    def name(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    def tpe(self) -> 'PType': ...
    @staticmethod
    def unapply(x$0: 'CmdParameter') -> scala.Option[scala.Tuple7[java.lang.String, java.lang.String, 'PType', java.lang.String, scala.Option[java.lang.String], scala.Option[CmdArgInput], scala.Option[CmdArgParser]]]: ...

class CommandNamePType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class DefaultCmdArgParser:
    @staticmethod
    def parse(cmd: CmdDescriptor, p: CmdParameter, rawArg: typing.Union[java.lang.String, str]) -> typing.Any: ...

class DefaultParameterInput:
    @staticmethod
    def input(ctx: org.ergoplatform.appkit.cli.AppContext, cmd: CmdDescriptor, parameter: CmdParameter) -> typing.Any: ...

class DirPathPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class ErgoIdPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class ErgoToolException(java.lang.RuntimeException, scala.Product, scala.Serializable):
    def __init__(self, message: typing.Union[java.lang.String, str], cause: java.lang.Throwable): ...
    @staticmethod
    def $lessinit$greater$default$2() -> java.lang.Throwable: ...
    @staticmethod
    def apply(message: typing.Union[java.lang.String, str], cause: java.lang.Throwable) -> 'ErgoToolException': ...
    @staticmethod
    def apply$default$2() -> java.lang.Throwable: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cause(self) -> java.lang.Throwable: ...
    def copy(self, message: typing.Union[java.lang.String, str], cause: java.lang.Throwable) -> 'ErgoToolException': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> java.lang.Throwable: ...
    @staticmethod
    def curried() -> scala.Function1[java.lang.String, scala.Function1[java.lang.Throwable, 'ErgoToolException']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def message(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[java.lang.String, java.lang.Throwable], 'ErgoToolException']: ...
    @staticmethod
    def unapply(x$0: 'ErgoToolException') -> scala.Option[scala.Tuple2[java.lang.String, java.lang.Throwable]]: ...

class FilePType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class FilePathPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class IntPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class LongPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class NanoErgPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class NetworkPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class NewPasswordInput:
    @staticmethod
    def input(ctx: org.ergoplatform.appkit.cli.AppContext, cmd: CmdDescriptor, param: CmdParameter) -> typing.Any: ...

class PType:
    def __init__(self): ...

class PasswordInput:
    @staticmethod
    def input(ctx: org.ergoplatform.appkit.cli.AppContext, cmd: CmdDescriptor, param: CmdParameter) -> typing.Any: ...

class RunWithErgoClient:
    @staticmethod
    def $init$($this: 'RunWithErgoClient') -> None: ...
    def run(self, ctx: org.ergoplatform.appkit.cli.AppContext) -> None: ...
    def runWithClient(self, ergoClient: org.ergoplatform.appkit.ErgoClient, ctx: org.ergoplatform.appkit.cli.AppContext) -> None: ...

class SecretStringPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class StringPType:
    @staticmethod
    def canEqual(x$1: typing.Any) -> bool: ...
    @staticmethod
    def hashCode() -> int: ...
    @staticmethod
    def productArity() -> int: ...
    @staticmethod
    def productElement(x$1: int) -> typing.Any: ...
    @staticmethod
    def productIterator() -> scala.collection.Iterator[typing.Any]: ...
    @staticmethod
    def productPrefix() -> java.lang.String: ...
    @staticmethod
    def toString() -> java.lang.String: ...

class UsageException(java.lang.RuntimeException, scala.Product, scala.Serializable):
    def __init__(self, message: typing.Union[java.lang.String, str], cmdDescOpt: scala.Option[CmdDescriptor]): ...
    @staticmethod
    def apply(message: typing.Union[java.lang.String, str], cmdDescOpt: scala.Option[CmdDescriptor]) -> 'UsageException': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cmdDescOpt(self) -> scala.Option[CmdDescriptor]: ...
    def copy(self, message: typing.Union[java.lang.String, str], cmdDescOpt: scala.Option[CmdDescriptor]) -> 'UsageException': ...
    def copy$default$1(self) -> java.lang.String: ...
    def copy$default$2(self) -> scala.Option[CmdDescriptor]: ...
    @staticmethod
    def curried() -> scala.Function1[java.lang.String, scala.Function1[scala.Option[CmdDescriptor], 'UsageException']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def message(self) -> java.lang.String: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[java.lang.String, scala.Option[CmdDescriptor]], 'UsageException']: ...
    @staticmethod
    def unapply(x$0: 'UsageException') -> scala.Option[scala.Tuple2[java.lang.String, scala.Option[CmdDescriptor]]]: ...

class package:
    @staticmethod
    def usageError(msg: typing.Union[java.lang.String, str], cmdDescOpt: scala.Option[CmdDescriptor]) -> scala.runtime.Nothing.: ...

class EnumPType(PType, scala.Product, scala.Serializable):
    def __init__(self, values: scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], typing.Any]]): ...
    _andThen__A = typing.TypeVar('_andThen__A')  # <A>
    @staticmethod
    def andThen(g: scala.Function1['EnumPType', _andThen__A]) -> scala.Function1[scala.collection.Seq[scala.Tuple2[java.lang.String, typing.Any]], _andThen__A]: ...
    @staticmethod
    def apply(values: scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], typing.Any]]) -> 'EnumPType': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    _compose__A = typing.TypeVar('_compose__A')  # <A>
    @staticmethod
    def compose(g: scala.Function1[_compose__A, scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], typing.Any]]]) -> scala.Function1[_compose__A, 'EnumPType']: ...
    def copy(self, values: scala.collection.Seq[scala.Tuple2[typing.Union[java.lang.String, str], typing.Any]]) -> 'EnumPType': ...
    def copy$default$1(self) -> scala.collection.Seq[scala.Tuple2[java.lang.String, typing.Any]]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def getByName(self, name: typing.Union[java.lang.String, str]) -> scala.Option[typing.Any]: ...
    def hashCode(self) -> int: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def toString(self) -> java.lang.String: ...
    @staticmethod
    def unapply(x$0: 'EnumPType') -> scala.Option[scala.collection.Seq[scala.Tuple2[java.lang.String, typing.Any]]]: ...
    def values(self) -> scala.collection.Seq[scala.Tuple2[java.lang.String, typing.Any]]: ...

class EnumParser(CmdArgParser):
    def __init__(self, enum: EnumPType): ...
    def parse(self, cmd: CmdDescriptor, p: CmdParameter, rawArg: typing.Union[java.lang.String, str]) -> typing.Any: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.appkit.commands")``.

    AddressPType: typing.Type[AddressPType]
    BooleanPType: typing.Type[BooleanPType]
    Cmd: typing.Type[Cmd]
    CmdArgInput: typing.Type[CmdArgInput]
    CmdArgParser: typing.Type[CmdArgParser]
    CmdDescriptor: typing.Type[CmdDescriptor]
    CmdException: typing.Type[CmdException]
    CmdParameter: typing.Type[CmdParameter]
    CommandNamePType: typing.Type[CommandNamePType]
    DefaultCmdArgParser: typing.Type[DefaultCmdArgParser]
    DefaultParameterInput: typing.Type[DefaultParameterInput]
    DirPathPType: typing.Type[DirPathPType]
    EnumPType: typing.Type[EnumPType]
    EnumParser: typing.Type[EnumParser]
    ErgoIdPType: typing.Type[ErgoIdPType]
    ErgoToolException: typing.Type[ErgoToolException]
    FilePType: typing.Type[FilePType]
    FilePathPType: typing.Type[FilePathPType]
    IntPType: typing.Type[IntPType]
    LongPType: typing.Type[LongPType]
    NanoErgPType: typing.Type[NanoErgPType]
    NetworkPType: typing.Type[NetworkPType]
    NewPasswordInput: typing.Type[NewPasswordInput]
    PType: typing.Type[PType]
    PasswordInput: typing.Type[PasswordInput]
    RunWithErgoClient: typing.Type[RunWithErgoClient]
    SecretStringPType: typing.Type[SecretStringPType]
    StringPType: typing.Type[StringPType]
    UsageException: typing.Type[UsageException]
    package: typing.Type[package]
